local addonName, addon = ...

local function RaidClassButton_OnDragStart(self, button)
  if InCombatLockdown() then return end
  RaidPulloutButton_OnDragStart(RaidPullout_GeneratePulloutFrame(self.fileName, self.class))
end

local function RaidGroupButton_OnDragStart(self, button)
  if InCombatLockdown() then return end
  if _G.UnitIsGroupLeader("player") or _G.UnitIsGroupAssistant("player") then
    if IsShiftKeyDown() then
      self.keypressed = "1"
      RaidPulloutButton_OnDragStart(RaidPullout_GeneratePulloutFrame(self.name, nil))
    else
      RaidGroupButton_OnDragStart(self)
      self.keypressed = nil
    end
  else
    RaidPulloutButton_OnDragStart(RaidPullout_GeneratePulloutFrame(self.name, nil))
  end
end

local function RaidGroupLabel_OnDragStart(self, button)
  if InCombatLockdown() then return end
  RaidPulloutButton_OnDragStart(RaidPullout_GeneratePulloutFrame(self:GetParent():GetID()))
end

local eventHandler = _G.CreateFrame("Frame")
eventHandler:HookScript("OnEvent", function(_, event, ...)
  return addon[event](...)
end)

function addon.ADDON_LOADED(name)
  if name ~= "Blizzard_RaidUI" then return end

  eventHandler:UnregisterEvent("ADDON_LOADED")

  -- There's technically 14 of these, but showing RaidClassButton14 causes some issues.  I don't know what this button
  -- does either and it was added after the RaidClassButtonTemplate was changed so that these frames are hidden by
  -- default.  Maybe it used to be RaidClassButton13 and was shifted up when Monks were added (and something broke?).
  for i = 1, 13 do
    local raidClassButton = _G["RaidClassButton" .. i]
    raidClassButton:Show()
    raidClassButton:HookScript("OnDragStart", RaidClassButton_OnDragStart)
  end

  for i = 1, 40 do
    _G["RaidGroupButton" .. i]:HookScript("OnDragStart", RaidGroupButton_OnDragStart)
  end

  for i = 1, 8 do
    local raidGroupLabel = _G["RaidGroup" .. i .. "Label"]
    raidGroupLabel:RegisterForDrag("LeftButton")
    raidGroupLabel:HookScript("OnDragStart", RaidGroupLabel_OnDragStart)
    raidGroupLabel:HookScript("OnDragStop", function() if not InCombatLockdown() then RaidPulloutStopMoving() end end)
    raidGroupLabel:HookScript("OnHide", function() if not InCombatLockdown() then RaidPulloutStopMoving() end end)
  end

  eventHandler.ADDON_LOADED = nil
end

eventHandler:RegisterEvent("ADDON_LOADED")

-- github.com/tekkub/wow-ui-source
-- wow.gamepedia.com/Raid_list
-- wowprogramming.com/utils/xmlbrowser/test/AddOns/Blizzard_RaidUI/Blizzard_RaidUI.toc
-- wowprogramming.com/utils/xmlbrowser/test/AddOns/Blizzard_RaidUI/Blizzard_RaidUI.xml
-- wowprogramming.com/utils/xmlbrowser/test/AddOns/Blizzard_RaidUI/Blizzard_RaidUI.lua
-- http://us.battle.net/wow/en/forum/topic/1536256780#5
-- http://us.battle.net/wow/en/forum/topic/1127489004
-- http://www.mmo-champion.com/threads/1796299-Want-to-revert-back-to-the-old-drag-and-drop-Blizzard-UI-raid-frames

-- vim: tw=120 sts=2 sw=2 et
